@@ -1,6 +1,5 @@
 from .exceptions import NoInputError, NoPlayerFoundError
-import hypixel
-import mojang
+from . import hypixel, mojang
 
 
 class Hypixel:
