@@ -8,6 +8,12 @@ class MojangPlayer:
         self.name = data["name"]
         self.uuid = data["id"]
 
+    def __str__(self):
+        return self.name
+
+    def __int__(self):
+        return self.uuid
+
 
 class NameHistory:
     def __init__(self, data):
@@ -68,3 +74,6 @@ class Rank:
             data.get("player", {}).get("packageRank"),
         )
         self.color = utils.get_rank_color(self.name)
+
+    def __str__(self):
+        return self.name
\ No newline at end of file
